@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Input import Input
 
 # Import all class method
@@ -18,6 +21,11 @@ try:
 except ImportError as error:
     gen_input = error
 
+try:
+    from ..Methods.Simulation.InputFlux.comp_felec import comp_felec
+except ImportError as error:
+    comp_felec = error
+
 
 from ..Classes.ImportMatrixVal import ImportMatrixVal
 from numpy import ndarray
@@ -33,6 +41,7 @@ class InputFlux(Input):
 
     VERSION = 1
 
+    # Check ImportError to remove unnecessary dependencies in unused method
     # cf Methods.Simulation.InputFlux.gen_input
     if isinstance(gen_input, ImportError):
         gen_input = property(
@@ -42,15 +51,18 @@ class InputFlux(Input):
         )
     else:
         gen_input = gen_input
-    # save method is available in all object
+    # cf Methods.Simulation.InputFlux.comp_felec
+    if isinstance(comp_felec, ImportError):
+        comp_felec = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use InputFlux method comp_felec: " + str(comp_felec))
+            )
+        )
+    else:
+        comp_felec = comp_felec
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -68,37 +80,16 @@ class InputFlux(Input):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if B == -1:
-            B = ImportVectorField()
-        if OP == -1:
-            OP = Input()
-        if time == -1:
-            time = ImportMatrix()
-        if angle == -1:
-            angle = ImportMatrix()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            B = obj.B
-            OP = obj.OP
-            time = obj.time
-            angle = obj.angle
-            Nt_tot = obj.Nt_tot
-            Nrev = obj.Nrev
-            Na_tot = obj.Na_tot
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -116,53 +107,9 @@ class InputFlux(Input):
                 Nrev = init_dict["Nrev"]
             if "Na_tot" in list(init_dict.keys()):
                 Na_tot = init_dict["Na_tot"]
-        # Initialisation by argument
-        # B can be None, a ImportVectorField object or a dict
-        if isinstance(B, dict):
-            self.B = ImportVectorField(init_dict=B)
-        elif isinstance(B, str):
-            from ..Functions.load import load
-
-            self.B = load(B)
-        else:
-            self.B = B
-        # OP can be None, a Input object or a dict
-        if isinstance(OP, dict):
-            # Check that the type is correct (including daughter)
-            class_name = OP.get("__class__")
-            if class_name not in [
-                "Input",
-                "InputCurrent",
-                "InputElec",
-                "InputFlux",
-                "InputForce",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for OP"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.OP = class_obj(init_dict=OP)
-        elif isinstance(OP, str):
-            from ..Functions.load import load
-
-            OP = load(OP)
-            # Check that the type is correct (including daughter)
-            class_name = OP.__class__.__name__
-            if class_name not in [
-                "Input",
-                "InputCurrent",
-                "InputElec",
-                "InputFlux",
-                "InputForce",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for OP"
-                )
-            self.OP = OP
-        else:
-            self.OP = OP
+        # Set the properties (value check and convertion are done in setter)
+        self.B = B
+        self.OP = OP
         # Call Input init
         super(InputFlux, self).__init__(
             time=time, angle=angle, Nt_tot=Nt_tot, Nrev=Nrev, Na_tot=Na_tot
@@ -171,7 +118,7 @@ class InputFlux(Input):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         InputFlux_str = ""
         # Get the properties inherited from Input
@@ -204,8 +151,7 @@ class InputFlux(Input):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Input
         InputFlux_dict = super(InputFlux, self).as_dict()
@@ -217,7 +163,7 @@ class InputFlux(Input):
             InputFlux_dict["OP"] = None
         else:
             InputFlux_dict["OP"] = self.OP.as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         InputFlux_dict["__class__"] = "InputFlux"
         return InputFlux_dict
@@ -238,6 +184,13 @@ class InputFlux(Input):
 
     def _set_B(self, value):
         """setter of B"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "B")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = ImportVectorField()
         check_var("B", value, "ImportVectorField")
         self._B = value
 
@@ -259,6 +212,13 @@ class InputFlux(Input):
 
     def _set_OP(self, value):
         """setter of OP"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "OP")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Input()
         check_var("OP", value, "Input")
         self._OP = value
 
