@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 from ._check import InitUnKnowClassError
@@ -19,15 +22,9 @@ class MatStructural(FrozenClass):
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -48,32 +45,16 @@ class MatStructural(FrozenClass):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            rho = obj.rho
-            Ex = obj.Ex
-            Ey = obj.Ey
-            Ez = obj.Ez
-            nu_xy = obj.nu_xy
-            nu_xz = obj.nu_xz
-            nu_yz = obj.nu_yz
-            Gxz = obj.Gxz
-            Gxy = obj.Gxy
-            Gyz = obj.Gyz
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -97,7 +78,7 @@ class MatStructural(FrozenClass):
                 Gxy = init_dict["Gxy"]
             if "Gyz" in list(init_dict.keys()):
                 Gyz = init_dict["Gyz"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.rho = rho
         self.Ex = Ex
@@ -114,7 +95,7 @@ class MatStructural(FrozenClass):
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         MatStructural_str = ""
         if self.parent is None:
@@ -163,8 +144,7 @@ class MatStructural(FrozenClass):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         MatStructural_dict = dict()
         MatStructural_dict["rho"] = self.rho
@@ -177,7 +157,7 @@ class MatStructural(FrozenClass):
         MatStructural_dict["Gxz"] = self.Gxz
         MatStructural_dict["Gxy"] = self.Gxy
         MatStructural_dict["Gyz"] = self.Gyz
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         MatStructural_dict["__class__"] = "MatStructural"
         return MatStructural_dict
 
