@@ -9,16 +9,12 @@ from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 from numpy import array, array_equal
-from cloudpickle import dumps, loads
-from ._check import CheckTypeError
-
-try:
-    from SciDataTool.Classes.DataND import DataND
-except ImportError:
-    DataND = ImportError
 from ._check import InitUnKnowClassError
 
 
@@ -27,22 +23,16 @@ class OutStruct(FrozenClass):
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
         self,
-        time=None,
-        angle=None,
+        Time=None,
+        Angle=None,
         Nt_tot=None,
         Na_tot=None,
         logger_name="Pyleecan.OutStruct",
@@ -54,37 +44,23 @@ class OutStruct(FrozenClass):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            time = obj.time
-            angle = obj.angle
-            Nt_tot = obj.Nt_tot
-            Na_tot = obj.Na_tot
-            logger_name = obj.logger_name
-            Yr = obj.Yr
-            Vr = obj.Vr
-            Ar = obj.Ar
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
-            if "time" in list(init_dict.keys()):
-                time = init_dict["time"]
-            if "angle" in list(init_dict.keys()):
-                angle = init_dict["angle"]
+            if "Time" in list(init_dict.keys()):
+                Time = init_dict["Time"]
+            if "Angle" in list(init_dict.keys()):
+                Angle = init_dict["Angle"]
             if "Nt_tot" in list(init_dict.keys()):
                 Nt_tot = init_dict["Nt_tot"]
             if "Na_tot" in list(init_dict.keys()):
@@ -97,18 +73,13 @@ class OutStruct(FrozenClass):
                 Vr = init_dict["Vr"]
             if "Ar" in list(init_dict.keys()):
                 Ar = init_dict["Ar"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        # time can be None, a ndarray or a list
-        set_array(self, "time", time)
-        # angle can be None, a ndarray or a list
-        set_array(self, "angle", angle)
+        self.Time = Time
+        self.Angle = Angle
         self.Nt_tot = Nt_tot
         self.Na_tot = Na_tot
         self.logger_name = logger_name
-        # Check if the type DataND has been imported with success
-        if isinstance(DataND, ImportError):
-            raise ImportError("Unknown type DataND please install SciDataTool")
         self.Yr = Yr
         self.Vr = Vr
         self.Ar = Ar
@@ -117,7 +88,7 @@ class OutStruct(FrozenClass):
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         OutStruct_str = ""
         if self.parent is None:
@@ -125,16 +96,16 @@ class OutStruct(FrozenClass):
         else:
             OutStruct_str += "parent = " + str(type(self.parent)) + " object" + linesep
         OutStruct_str += (
-            "time = "
+            "Time = "
             + linesep
-            + str(self.time).replace(linesep, linesep + "\t")
+            + str(self.Time).replace(linesep, linesep + "\t")
             + linesep
             + linesep
         )
         OutStruct_str += (
-            "angle = "
+            "Angle = "
             + linesep
-            + str(self.angle).replace(linesep, linesep + "\t")
+            + str(self.Angle).replace(linesep, linesep + "\t")
             + linesep
             + linesep
         )
@@ -151,9 +122,9 @@ class OutStruct(FrozenClass):
 
         if type(other) != type(self):
             return False
-        if not array_equal(other.time, self.time):
+        if not array_equal(other.Time, self.Time):
             return False
-        if not array_equal(other.angle, self.angle):
+        if not array_equal(other.Angle, self.Angle):
             return False
         if other.Nt_tot != self.Nt_tot:
             return False
@@ -170,54 +141,41 @@ class OutStruct(FrozenClass):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         OutStruct_dict = dict()
-        if self.time is None:
-            OutStruct_dict["time"] = None
+        if self.Time is None:
+            OutStruct_dict["Time"] = None
         else:
-            OutStruct_dict["time"] = self.time.tolist()
-        if self.angle is None:
-            OutStruct_dict["angle"] = None
+            OutStruct_dict["Time"] = self.Time.tolist()
+        if self.Angle is None:
+            OutStruct_dict["Angle"] = None
         else:
-            OutStruct_dict["angle"] = self.angle.tolist()
+            OutStruct_dict["Angle"] = self.Angle.tolist()
         OutStruct_dict["Nt_tot"] = self.Nt_tot
         OutStruct_dict["Na_tot"] = self.Na_tot
         OutStruct_dict["logger_name"] = self.logger_name
         if self.Yr is None:
             OutStruct_dict["Yr"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutStruct_dict["Yr"] = {
-                "__class__": str(type(self._Yr)),
-                "__repr__": str(self._Yr.__repr__()),
-                "serialized": dumps(self._Yr).decode("ISO-8859-2"),
-            }
+        else:
+            OutStruct_dict["Yr"] = self.Yr.as_dict()
         if self.Vr is None:
             OutStruct_dict["Vr"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutStruct_dict["Vr"] = {
-                "__class__": str(type(self._Vr)),
-                "__repr__": str(self._Vr.__repr__()),
-                "serialized": dumps(self._Vr).decode("ISO-8859-2"),
-            }
+        else:
+            OutStruct_dict["Vr"] = self.Vr.as_dict()
         if self.Ar is None:
             OutStruct_dict["Ar"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
-            OutStruct_dict["Ar"] = {
-                "__class__": str(type(self._Ar)),
-                "__repr__": str(self._Ar.__repr__()),
-                "serialized": dumps(self._Ar).decode("ISO-8859-2"),
-            }
-        # The class name is added to the dict fordeserialisation purpose
+        else:
+            OutStruct_dict["Ar"] = self.Ar.as_dict()
+        # The class name is added to the dict for deserialisation purpose
         OutStruct_dict["__class__"] = "OutStruct"
         return OutStruct_dict
 
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        self.time = None
-        self.angle = None
+        self.Time = None
+        self.Angle = None
         self.Nt_tot = None
         self.Na_tot = None
         self.logger_name = None
@@ -225,51 +183,51 @@ class OutStruct(FrozenClass):
         self.Vr = None
         self.Ar = None
 
-    def _get_time(self):
-        """getter of time"""
-        return self._time
+    def _get_Time(self):
+        """getter of Time"""
+        return self._Time
 
-    def _set_time(self, value):
-        """setter of time"""
-        if value is None:
+    def _set_Time(self, value):
+        """setter of Time"""
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
                 value = array(value)
             except:
                 pass
-        check_var("time", value, "ndarray")
-        self._time = value
+        check_var("Time", value, "ndarray")
+        self._Time = value
 
-    time = property(
-        fget=_get_time,
-        fset=_set_time,
-        doc=u"""Structural time vector (no symmetry)
+    Time = property(
+        fget=_get_Time,
+        fset=_set_Time,
+        doc=u"""Structural time Data object
 
         :Type: ndarray
         """,
     )
 
-    def _get_angle(self):
-        """getter of angle"""
-        return self._angle
+    def _get_Angle(self):
+        """getter of Angle"""
+        return self._Angle
 
-    def _set_angle(self, value):
-        """setter of angle"""
-        if value is None:
+    def _set_Angle(self, value):
+        """setter of Angle"""
+        if type(value) is int and value == -1:
             value = array([])
         elif type(value) is list:
             try:
                 value = array(value)
             except:
                 pass
-        check_var("angle", value, "ndarray")
-        self._angle = value
+        check_var("Angle", value, "ndarray")
+        self._Angle = value
 
-    angle = property(
-        fget=_get_angle,
-        fset=_set_angle,
-        doc=u"""Structural position vector (no symmetry)
+    Angle = property(
+        fget=_get_Angle,
+        fset=_set_Angle,
+        doc=u"""Structural position Data object
 
         :Type: ndarray
         """,
@@ -335,17 +293,17 @@ class OutStruct(FrozenClass):
 
     def _set_Yr(self, value):
         """setter of Yr"""
-        try:  # Check the type
-            check_var("Yr", value, "dict")
-        except CheckTypeError:
-            check_var("Yr", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Yr = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Yr = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Yr"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Yr", value, "DataND")
+        self._Yr = value
 
     Yr = property(
         fget=_get_Yr,
@@ -362,17 +320,17 @@ class OutStruct(FrozenClass):
 
     def _set_Vr(self, value):
         """setter of Vr"""
-        try:  # Check the type
-            check_var("Vr", value, "dict")
-        except CheckTypeError:
-            check_var("Vr", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Vr = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Vr = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Vr"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Vr", value, "DataND")
+        self._Vr = value
 
     Vr = property(
         fget=_get_Vr,
@@ -389,17 +347,17 @@ class OutStruct(FrozenClass):
 
     def _set_Ar(self, value):
         """setter of Ar"""
-        try:  # Check the type
-            check_var("Ar", value, "dict")
-        except CheckTypeError:
-            check_var("Ar", value, "SciDataTool.Classes.DataND.DataND")
-            # property can be set from a list to handle loads
-        if (
-            type(value) == dict
-        ):  # Load type from saved dict {"type":type(value),"str": str(value),"serialized": serialized(value)]
-            self._Ar = loads(value["serialized"].encode("ISO-8859-2"))
-        else:
-            self._Ar = value
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Ar"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Ar", value, "DataND")
+        self._Ar = value
 
     Ar = property(
         fget=_get_Ar,
