@@ -61,6 +61,16 @@ try:
 except ImportError as error:
     comp_surface_wind = error
 
+try:
+    from ..Methods.Slot.SlotW13.get_surface_wind import get_surface_wind
+except ImportError as error:
+    get_surface_wind = error
+
+try:
+    from ..Methods.Slot.SlotW13.get_H1 import get_H1
+except ImportError as error:
+    get_H1 = error
+
 
 from ._check import InitUnKnowClassError
 
@@ -172,6 +182,27 @@ class SlotW13(SlotWind):
         )
     else:
         comp_surface_wind = comp_surface_wind
+    # cf Methods.Slot.SlotW13.get_surface_wind
+    if isinstance(get_surface_wind, ImportError):
+        get_surface_wind = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotW13 method get_surface_wind: "
+                    + str(get_surface_wind)
+                )
+            )
+        )
+    else:
+        get_surface_wind = get_surface_wind
+    # cf Methods.Slot.SlotW13.get_H1
+    if isinstance(get_H1, ImportError):
+        get_H1 = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use SlotW13 method get_H1: " + str(get_H1))
+            )
+        )
+    else:
+        get_H1 = get_H1
     # save and copy methods are available in all object
     save = save
     copy = copy
