@@ -22,9 +22,9 @@ except ImportError as error:
     build_geometry = error
 
 try:
-    from ..Methods.Slot.SlotW22.build_geometry_wind import build_geometry_wind
+    from ..Methods.Slot.SlotW22.get_surface_wind import get_surface_wind
 except ImportError as error:
-    build_geometry_wind = error
+    get_surface_wind = error
 
 try:
     from ..Methods.Slot.SlotW22.check import check
@@ -56,6 +56,11 @@ try:
 except ImportError as error:
     comp_surface_wind = error
 
+try:
+    from ..Methods.Slot.SlotW22.build_geometry_wind import build_geometry_wind
+except ImportError as error:
+    build_geometry_wind = error
+
 
 from ._check import InitUnKnowClassError
 
@@ -78,18 +83,18 @@ class SlotW22(SlotWind):
         )
     else:
         build_geometry = build_geometry
-    # cf Methods.Slot.SlotW22.build_geometry_wind
-    if isinstance(build_geometry_wind, ImportError):
-        build_geometry_wind = property(
+    # cf Methods.Slot.SlotW22.get_surface_wind
+    if isinstance(get_surface_wind, ImportError):
+        get_surface_wind = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use SlotW22 method build_geometry_wind: "
-                    + str(build_geometry_wind)
+                    "Can't use SlotW22 method get_surface_wind: "
+                    + str(get_surface_wind)
                 )
             )
         )
     else:
-        build_geometry_wind = build_geometry_wind
+        get_surface_wind = get_surface_wind
     # cf Methods.Slot.SlotW22.check
     if isinstance(check, ImportError):
         check = property(
@@ -155,6 +160,18 @@ class SlotW22(SlotWind):
         )
     else:
         comp_surface_wind = comp_surface_wind
+    # cf Methods.Slot.SlotW22.build_geometry_wind
+    if isinstance(build_geometry_wind, ImportError):
+        build_geometry_wind = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotW22 method build_geometry_wind: "
+                    + str(build_geometry_wind)
+                )
+            )
+        )
+    else:
+        build_geometry_wind = build_geometry_wind
     # save and copy methods are available in all object
     save = save
     copy = copy
