@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .VarSimu import VarSimu
 
 # Import all class method
@@ -23,10 +26,16 @@ try:
 except ImportError as error:
     get_simulations = error
 
+try:
+    from ..Methods.Simulation.VarParam.get_simu_number import get_simu_number
+except ImportError as error:
+    get_simu_number = error
+
 
 from ._check import InitUnKnowClassError
 from .ParamExplorer import ParamExplorer
 from .DataKeeper import DataKeeper
+from .Post import Post
 
 
 class VarParam(VarSimu):
@@ -57,59 +66,50 @@ class VarParam(VarSimu):
         )
     else:
         get_simulations = get_simulations
-    # save method is available in all object
+    # cf Methods.Simulation.VarParam.get_simu_number
+    if isinstance(get_simu_number, ImportError):
+        get_simu_number = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use VarParam method get_simu_number: " + str(get_simu_number)
+                )
+            )
+        )
+    else:
+        get_simu_number = get_simu_number
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
         self,
-        paramexplorer_list=list(),
+        paramexplorer_list=-1,
         name="",
         desc="",
-        datakeeper_list=list(),
-        nb_proc=1,
+        datakeeper_list=-1,
         is_keep_all_output=False,
         stop_if_error=False,
         ref_simu_index=None,
         nb_simu=0,
+        is_reuse_femm_file=True,
+        postproc_list=-1,
         init_dict=None,
         init_str=None,
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            paramexplorer_list = obj.paramexplorer_list
-            name = obj.name
-            desc = obj.desc
-            datakeeper_list = obj.datakeeper_list
-            nb_proc = obj.nb_proc
-            is_keep_all_output = obj.is_keep_all_output
-            stop_if_error = obj.stop_if_error
-            ref_simu_index = obj.ref_simu_index
-            nb_simu = obj.nb_simu
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -121,8 +121,6 @@ class VarParam(VarSimu):
                 desc = init_dict["desc"]
             if "datakeeper_list" in list(init_dict.keys()):
                 datakeeper_list = init_dict["datakeeper_list"]
-            if "nb_proc" in list(init_dict.keys()):
-                nb_proc = init_dict["nb_proc"]
             if "is_keep_all_output" in list(init_dict.keys()):
                 is_keep_all_output = init_dict["is_keep_all_output"]
             if "stop_if_error" in list(init_dict.keys()):
@@ -131,54 +129,29 @@ class VarParam(VarSimu):
                 ref_simu_index = init_dict["ref_simu_index"]
             if "nb_simu" in list(init_dict.keys()):
                 nb_simu = init_dict["nb_simu"]
-        # Initialisation by argument
-        # paramexplorer_list can be None or a list of ParamExplorer object
-        self.paramexplorer_list = list()
-        if type(paramexplorer_list) is list:
-            for obj in paramexplorer_list:
-                if obj is None:  # Default value
-                    self.paramexplorer_list.append(ParamExplorer())
-                elif isinstance(obj, dict):
-                    # Check that the type is correct (including daughter)
-                    class_name = obj.get("__class__")
-                    if class_name not in [
-                        "ParamExplorer",
-                        "OptiDesignVar",
-                        "ParamExplorerSet",
-                    ]:
-                        raise InitUnKnowClassError(
-                            "Unknow class name "
-                            + class_name
-                            + " in init_dict for paramexplorer_list"
-                        )
-                    # Dynamic import to call the correct constructor
-                    module = __import__(
-                        "pyleecan.Classes." + class_name, fromlist=[class_name]
-                    )
-                    class_obj = getattr(module, class_name)
-                    self.paramexplorer_list.append(class_obj(init_dict=obj))
-                else:
-                    self.paramexplorer_list.append(obj)
-        elif paramexplorer_list is None:
-            self.paramexplorer_list = list()
-        else:
-            self.paramexplorer_list = paramexplorer_list
+            if "is_reuse_femm_file" in list(init_dict.keys()):
+                is_reuse_femm_file = init_dict["is_reuse_femm_file"]
+            if "postproc_list" in list(init_dict.keys()):
+                postproc_list = init_dict["postproc_list"]
+        # Set the properties (value check and convertion are done in setter)
+        self.paramexplorer_list = paramexplorer_list
         # Call VarSimu init
         super(VarParam, self).__init__(
             name=name,
             desc=desc,
             datakeeper_list=datakeeper_list,
-            nb_proc=nb_proc,
             is_keep_all_output=is_keep_all_output,
             stop_if_error=stop_if_error,
             ref_simu_index=ref_simu_index,
             nb_simu=nb_simu,
+            is_reuse_femm_file=is_reuse_femm_file,
+            postproc_list=postproc_list,
         )
         # The class is frozen (in VarSimu init), for now it's impossible to
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         VarParam_str = ""
         # Get the properties inherited from VarSimu
@@ -209,15 +182,17 @@ class VarParam(VarSimu):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from VarSimu
         VarParam_dict = super(VarParam, self).as_dict()
-        VarParam_dict["paramexplorer_list"] = list()
-        for obj in self.paramexplorer_list:
-            VarParam_dict["paramexplorer_list"].append(obj.as_dict())
-        # The class name is added to the dict fordeserialisation purpose
+        if self.paramexplorer_list is None:
+            VarParam_dict["paramexplorer_list"] = None
+        else:
+            VarParam_dict["paramexplorer_list"] = list()
+            for obj in self.paramexplorer_list:
+                VarParam_dict["paramexplorer_list"].append(obj.as_dict())
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         VarParam_dict["__class__"] = "VarParam"
         return VarParam_dict
@@ -232,20 +207,26 @@ class VarParam(VarSimu):
 
     def _get_paramexplorer_list(self):
         """getter of paramexplorer_list"""
-        for obj in self._paramexplorer_list:
-            if obj is not None:
-                obj.parent = self
+        if self._paramexplorer_list is not None:
+            for obj in self._paramexplorer_list:
+                if obj is not None:
+                    obj.parent = self
         return self._paramexplorer_list
 
     def _set_paramexplorer_list(self, value):
         """setter of paramexplorer_list"""
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "paramexplorer_list"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+        if value == -1:
+            value = list()
         check_var("paramexplorer_list", value, "[ParamExplorer]")
         self._paramexplorer_list = value
 
-        for obj in self._paramexplorer_list:
-            if obj is not None:
-                obj.parent = self
-
     paramexplorer_list = property(
         fget=_get_paramexplorer_list,
         fset=_set_paramexplorer_list,
