@@ -1,13 +1,16 @@
 from numpy import zeros
-from femm import mo_getcircuitproperties
 
 
-def comp_FEMM_Phi_wind(qs, Npcpp, is_stator, Lfemm, L1, sym, is_rescale_flux=True):
+def comp_FEMM_Phi_wind(
+    femm, qs, Npcpp, is_stator, Lfemm, L1, sym, is_rescale_flux=True
+):
     """Compute the total fluxlinkage of the winding phases
 
     Parameters
     ----------
-    qs : int 
+    femm : FEMMHandler
+        client to send command to a FEMM instance
+    qs : int
         number of phases
     Npcpp : int
         number of parallel circuits per phase (maximum 2p)
@@ -16,7 +19,7 @@ def comp_FEMM_Phi_wind(qs, Npcpp, is_stator, Lfemm, L1, sym, is_rescale_flux=Tru
     Lfemm : float
         lenght of FEMM model
     L1 : float
-        actual lenght for rescaling fluxlinkage 
+        actual lenght for rescaling fluxlinkage
     sym : int
         symmetry factor (ie. 1 = full machine, 2 = half machine ...)
     is_rescale_flux : bool
@@ -37,7 +40,7 @@ def comp_FEMM_Phi_wind(qs, Npcpp, is_stator, Lfemm, L1, sym, is_rescale_flux=Tru
 
     # For each phase/circuit
     for q in range(qs):
-        PropCirc = mo_getcircuitproperties(label + str(q))
+        PropCirc = femm.mo_getcircuitproperties(label + str(q))
         # rescaling to account for end winding flux
         if is_rescale_flux:
             Kphi = L1 / Lfemm
