@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import femm
 from numpy import exp, pi
 
 from ...Functions.FEMM import GROUP_FM
@@ -10,6 +9,7 @@ from ...Functions.FEMM.create_FEMM_magnet import create_FEMM_magnet
 
 
 def create_FEMM_materials(
+    femm,
     machine,
     surf_list,
     Is,
@@ -27,6 +27,8 @@ def create_FEMM_materials(
 
     Parameters
     ----------
+    femm : FEMMHandler
+        client to send command to a FEMM instance
     machine : Machine
         the machine to simulate
     surf_list : list
@@ -112,29 +114,22 @@ def create_FEMM_materials(
                 femm.mi_addmaterial("Air", 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0)
                 materials.append("Air")
             prop_dict[label] = "Air"
-        elif "BarR" in label:  # Squirrel cage
-            prop, materials = create_FEMM_bar(
-                is_mmfr, rotor.mat_type.elec.rho, materials
-            )
-            prop_dict[label] = prop
-        elif "WindR" in label:  # Rotor Winding
+        elif "Wind" in label or "Bar" in label:
+            I = Is if "Stator" in label else Ir
+            is_mmf = is_mmfs if "Stator" in label else is_mmfr
+            lam = stator if "Stator" in label else rotor
             prop, materials, circuits = create_FEMM_circuit_material(
-                circuits, label, is_eddies, rotor, Ir, is_mmfr, j_t0, materials
-            )
-            prop_dict[label] = prop
-        elif "WindS" in label:  # Stator Winding
-            prop, materials, circuits = create_FEMM_circuit_material(
-                circuits, label, is_eddies, stator, Is, is_mmfs, j_t0, materials
+                femm, circuits, label, is_eddies, lam, I, is_mmf, j_t0, materials
             )
             prop_dict[label] = prop
         elif "Magnet" in label and "Rotor" in label:  # Rotor Magnet
             prop, materials = create_FEMM_magnet(
-                label, is_mmfr, is_eddies, materials, rotor
+                femm, label, is_mmfr, is_eddies, materials, rotor
             )
             prop_dict[label] = prop
         elif "Magnet" in label and "Stator" in label:  # Stator Magnet
             prop, materials = create_FEMM_magnet(
-                label, is_mmfs, is_eddies, materials, stator
+                femm, label, is_mmfs, is_eddies, materials, stator
             )
             prop_dict[label] = prop
         elif "No_mesh" in label:  # Sliding band
