@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
-import femm
 from numpy import linalg as LA
 
 
-def set_FEMM_circuit_prop(circuits, Clabel, I, is_mmf, Npcpp, j_t0):
+def set_FEMM_circuit_prop(femm, circuits, Clabel, I, is_mmf, Npcpp, j_t0):
     """Create or update the property of a circuit
 
     Parameters
     ----------
+    femm : FEMMHandler
+        client to send command to a FEMM instance
     circuits: list
         list the name of all circuits
     label: str
@@ -34,13 +35,15 @@ def set_FEMM_circuit_prop(circuits, Clabel, I, is_mmf, Npcpp, j_t0):
     q_id = int(Clabel[5:])
     if I is not None:
         I = I.values
-    if Clabel in circuits:
-        if I is not None and I.size != 0 and LA.norm(I) != 0:
-            # Update existing circuit
-            femm.mi_modifycircprop(Clabel, 1, is_mmf * I[q_id, j_t0] / Npcpp)
-    else:
+    if Clabel not in circuits:
         # Create new circuit
         femm.mi_addcircprop(Clabel, 0, 1)
         circuits.append(Clabel)
 
+    # Update circuit
+    if I is not None and I.size != 0 and LA.norm(I) != 0:
+        femm.mi_modifycircprop(Clabel, 1, is_mmf * I[q_id, j_t0] / Npcpp)
+    else:
+        femm.mi_modifycircprop(Clabel, 1, 0)
+
     return circuits
