@@ -9,8 +9,7 @@ from pyleecan.GUI.Dialog.DMachineSetup.SMagnet.PMagnet11.Ui_PMagnet11 import (
 
 class Gen_PMagnet11(Ui_PMagnet11):
     def setupUi(self, PMagnet11):
-        """Abstract class to update the widget according to the csv doc
-        """
+        """Abstract class to update the widget according to the csv doc"""
         Ui_PMagnet11.setupUi(self, PMagnet11)
         # Setup of in_Hmag
         txt = self.tr(u"""magnet radial height [m]""")
