@@ -202,19 +202,19 @@ class PWSlot10(Gen_PWSlot10, QWidget):
 
         # Check that everything is set
         if lam.slot.W0 is None:
-            return translate("You must set W0 !", "PWSlot10")
+            return translate("You must set W0 !", "PWSlot10 check")
         elif lam.slot.W1 is None:
-            return translate("You must set W1 !", "PWSlot10")
+            return translate("You must set W1 !", "PWSlot10 check")
         elif lam.slot.W2 is None:
-            return translate("You must set W2 !", "PWSlot10")
+            return translate("You must set W2 !", "PWSlot10 check")
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot10")
+            return translate("You must set H0 !", "PWSlot10 check")
         elif lam.slot.H1 is None:
-            return translate("You must set H1 !", "PWSlot10")
+            return translate("You must set H1 !", "PWSlot10 check")
         elif lam.slot.H2 is None:
-            return translate("You must set H2 !", "PWSlot10")
+            return translate("You must set H2 !", "PWSlot10 check")
         elif lam.slot.H1 >= pi / 2:
-            return translate("You must have H1 < 90°", "PWSlot10")
+            return translate("You must have H1 < 90°", "PWSlot10 check")
 
         # Constraints
         try:
