@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-import PyQt5.QtCore
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QWidget
+import PySide2.QtCore
+from PySide2.QtCore import Signal
+from PySide2.QtWidgets import QWidget
 
 from ......Classes.SlotW14 import SlotW14
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot14.Gen_PWSlot14 import Gen_PWSlot14
 from ......Methods.Slot.Slot.check import SlotCheckError
 
-translate = PyQt5.QtCore.QCoreApplication.translate
+translate = PySide2.QtCore.QCoreApplication.translate
 
 
 class PWSlot14(Gen_PWSlot14, QWidget):
-    """Page to set the Slot Type 14
-    """
+    """Page to set the Slot Type 14"""
 
     # Signal to DMachineSetup to know that the save popup is needed
-    saveNeeded = pyqtSignal()
+    saveNeeded = Signal()
     # Information for Slot combobox
     slot_name = "Slot Type 14"
     slot_type = SlotW14
@@ -157,15 +156,15 @@ class PWSlot14(Gen_PWSlot14, QWidget):
 
         # Check that everything is set
         if lam.slot.W0 is None:
-            return translate("You must set W0 !", "PWSlot14")
+            return translate("You must set W0 !", "PWSlot14 check")
         elif lam.slot.W3 is None:
-            return translate("You must set W3 !", "PWSlot14")
+            return translate("You must set W3 !", "PWSlot14 check")
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot14")
+            return translate("You must set H0 !", "PWSlot14 check")
         elif lam.slot.H1 is None:
-            return translate("You must set H1 !", "PWSlot14")
+            return translate("You must set H1 !", "PWSlot14 check")
         elif lam.slot.H3 is None:
-            return translate("You must set H3 !", "PWSlot14")
+            return translate("You must set H3 !", "PWSlot14 check")
 
         # Check that everything is set right
         # Constraints
@@ -181,5 +180,5 @@ class PWSlot14(Gen_PWSlot14, QWidget):
             return translate("Unable to compute yoke height:", "PWSlot14") + str(error)
         if yoke_height <= 0:
             return translate(
-                "The slot height is greater than the lamination !", "PWSlot14"
+                "The slot height is greater than the lamination !", "PWSlot14 yoke"
             )
