@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-import PyQt5.QtCore
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QWidget
+import PySide2.QtCore
+from PySide2.QtCore import Signal
+from PySide2.QtWidgets import QWidget
 
 from ......Classes.SlotW16 import SlotW16
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot16.Gen_PWSlot16 import Gen_PWSlot16
 from ......Methods.Slot.Slot.check import SlotCheckError
 
-translate = PyQt5.QtCore.QCoreApplication.translate
+translate = PySide2.QtCore.QCoreApplication.translate
 
 
 class PWSlot16(Gen_PWSlot16, QWidget):
-    """Page to set the Slot Type 16
-    """
+    """Page to set the Slot Type 16"""
 
     # Signal to DMachineSetup to know that the save popup is needed
-    saveNeeded = pyqtSignal()
+    saveNeeded = Signal()
     # Information for Slot combobox
     slot_name = "Slot Type 16"
     slot_type = SlotW16
@@ -150,15 +149,15 @@ class PWSlot16(Gen_PWSlot16, QWidget):
 
         # Check that everything is set
         if lam.slot.W0 is None:
-            return translate("You must set W0 !", "PWSlot16")
+            return translate("You must set W0 !", "PWSlot16 check")
         elif lam.slot.W3 is None:
-            return translate("You must set W3 !", "PWSlot16")
+            return translate("You must set W3 !", "PWSlot16 check")
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot16")
+            return translate("You must set H0 !", "PWSlot16 check")
         elif lam.slot.H2 is None:
-            return translate("You must set H2 !", "PWSlot16")
+            return translate("You must set H2 !", "PWSlot16 check")
         elif lam.slot.R1 is None:
-            return translate("You must set R1 !", "PWSlot16")
+            return translate("You must set R1 !", "PWSlot16 check")
 
         # Check that everything is set right
         # Constraints
