@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 
 from numpy import pi
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QMessageBox, QWidget
+from PySide2.QtCore import Signal
+from PySide2.QtWidgets import QMessageBox, QWidget
 
 from .....Classes.LamSlotWind import LamSlotWind
 from .....Classes.Slot import Slot
 from .....Classes.SlotW10 import SlotW10
 from .....Classes.SlotWind import SlotWind
 from .....GUI.Dialog.DMachineSetup.SWSlot.Gen_SWSlot import Gen_SWSlot
+from .....GUI.Dialog.DMachineSetup.SWSlot.PWSlotUD.PWSlotUD import PWSlotUD
 from .....GUI.Dialog.DMachineSetup.SWSlot.PWSlot10.PWSlot10 import PWSlot10
 from .....GUI.Dialog.DMachineSetup.SWSlot.PWSlot11.PWSlot11 import PWSlot11
 from .....GUI.Dialog.DMachineSetup.SWSlot.PWSlot12.PWSlot12 import PWSlot12
@@ -44,17 +45,17 @@ WIDGET_LIST = [
     PWSlot27,
     PWSlot28,
     PWSlot29,
+    PWSlotUD,
 ]
 INIT_INDEX = [wid.slot_type for wid in WIDGET_LIST]
 SLOT_NAME = [wid.slot_name for wid in WIDGET_LIST]
 
 
 class SWSlot(Gen_SWSlot, QWidget):
-    """Step to set the slot with winding
-    """
+    """Step to set the slot with winding"""
 
     # Signal to DMachineSetup to know that the save popup is needed
-    saveNeeded = pyqtSignal()
+    saveNeeded = Signal()
     # Information for DMachineSetup nav
     step_name = "Slot"
 
@@ -68,7 +69,7 @@ class SWSlot(Gen_SWSlot, QWidget):
         machine : Machine
             current machine to edit
         matlib : MatLib
-            Material Library 
+            Material Library
         is_stator : bool
             To adapt the GUI to set either the stator or the rotor
         """
@@ -124,8 +125,7 @@ class SWSlot(Gen_SWSlot, QWidget):
         self.b_plot.clicked.connect(self.s_plot)
 
     def emit_save(self):
-        """Send a saveNeeded signal to the DMachineSetup
-        """
+        """Send a saveNeeded signal to the DMachineSetup"""
         self.saveNeeded.emit()
 
     def set_slot_type(self, index):
@@ -133,7 +133,7 @@ class SWSlot(Gen_SWSlot, QWidget):
 
         Parameters
         ----------
-        self : SWSlot 
+        self : SWSlot
             A SWSlot object
         index : int
             Index of the selected slot type in the list
@@ -167,7 +167,7 @@ class SWSlot(Gen_SWSlot, QWidget):
 
         Parameters
         ----------
-        self : SWSlot 
+        self : SWSlot
             A SWSlot object
         """
         value = self.si_Zs.value()
@@ -183,7 +183,7 @@ class SWSlot(Gen_SWSlot, QWidget):
 
         Parameters
         ----------
-        self : SWSlot 
+        self : SWSlot
             A SWSlot object
         Zs : int
             The current value of Zs
