@@ -8,6 +8,7 @@ from ....Functions.Winding.gen_phase_list import gen_name
 from ....Functions.init_fig import init_fig
 from ....definitions import config_dict
 from ....Classes.WindingSC import WindingSC
+from ....Classes.Winding import Winding
 
 PHASE_COLORS = config_dict["PLOT"]["COLOR_DICT"]["PHASE_COLORS"]
 ROTOR_COLOR = config_dict["PLOT"]["COLOR_DICT"]["ROTOR_COLOR"]
@@ -17,13 +18,14 @@ STATOR_COLOR = config_dict["PLOT"]["COLOR_DICT"]["STATOR_COLOR"]
 def plot(
     self,
     fig=None,
+    ax=None,
     is_lam_only=False,
     sym=1,
     alpha=0,
     delta=0,
     is_edge_only=False,
     is_display=True,
-    is_show=True,
+    is_show_fig=True,
 ):
     """Plot the Lamination in a matplotlib fig
 
@@ -31,9 +33,10 @@ def plot(
     ----------
     self : LamSlotWind
         A LamSlotWind object
-    fig :
-        if None, open a new fig and plot, else add to the current
-        one (Default value = None)
+    fig : Matplotlib.figure.Figure
+        existing figure to use if None create a new one
+    ax : Matplotlib.axes.Axes object
+        Axis on which to plot the data
     is_lam_only : bool
         True to plot only the lamination (remove the Winding)
     sym : int
@@ -46,7 +49,7 @@ def plot(
         To plot transparent Patches
     is_display : bool
         False to return the patches
-    is_show : bool
+    is_show_fig : bool
         To call show at the end of the method
     Returns
     -------
@@ -62,18 +65,22 @@ def plot(
     surf_list = self.build_geometry(sym=sym, alpha=alpha, delta=delta)
 
     patches = list()
-    # getting the matrix  wind_mat [Nrad,Ntan,Zs,qs] representing the winding
-    if type(self.winding) is WindingSC:
-        wind_mat = None
-    else:
-        try:
-            Zs = self.get_Zs()
-            wind_mat = self.winding.comp_connection_mat(Zs)
-            (Nrad, Ntan, Zs, qs) = wind_mat.shape
-        except Exception:
+    # getting the number of phases and winding connection matrix
+    if self.winding is not None and not type(self.winding) is Winding:
+        if isinstance(self.winding, WindingSC):  # plot only one phase for WindingSC
             wind_mat = None
-    if wind_mat is None:
-        qs = 1  # getting number of surface in winding Zone in the Slot
+            qs = 1
+        else:
+            try:
+                wind_mat = self.winding.comp_connection_mat(self.get_Zs())
+                qs = self.winding.qs
+            except:
+                wind_mat = None
+                qs = 1
+    else:
+        wind_mat = None
+        qs = 1
+
     for surf in surf_list:
         if surf.label is not None and "Lamination" in surf.label:
             patches.extend(surf.get_patches(color_lam, is_edge_only=is_edge_only))
@@ -86,7 +93,7 @@ def plot(
 
     if is_display:
         # Display the result
-        (fig, axes, patch_leg, label_leg) = init_fig(fig)
+        (fig, axes, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
         axes.set_xlabel("(m)")
         axes.set_ylabel("(m)")
         for patch in patches:
@@ -111,15 +118,23 @@ def plot(
                 axes.set_title("Rotor with Winding")
             # Add the winding legend only if needed
             if not is_lam_only:
-                phase_name = gen_name(qs, is_add_phase=True)
-                for ii in range(qs):
-                    if not phase_name[ii] in label_leg:
-                        # Avoid adding twice the same label
-                        index = ii % len(PHASE_COLORS)
-                        patch_leg.append(Patch(color=PHASE_COLORS[index]))
-                        label_leg.append(phase_name[ii])
+                if self.is_stator:
+                    prefix = "Stator "
+                else:
+                    prefix = "Rotor "
+                if isinstance(self.winding, WindingSC):
+                    patch_leg.append(Patch(color=PHASE_COLORS[0]))
+                    label_leg.append(prefix + "Bar")
+                elif self.winding is not None and not type(self.winding) is Winding:
+                    phase_name = [prefix + n for n in gen_name(qs, is_add_phase=True)]
+                    for ii in range(qs):
+                        if not phase_name[ii] in label_leg:
+                            # Avoid adding twice the same label
+                            index = ii % len(PHASE_COLORS)
+                            patch_leg.append(Patch(color=PHASE_COLORS[index]))
+                            label_leg.append(phase_name[ii])
             legend(patch_leg, label_leg)
-        if is_show:
+        if is_show_fig:
             fig.show()
     else:
         return patches
