@@ -11,12 +11,12 @@ class OptimizationAttributeError(Exception):
 
 
 def check_optimization_input(self):
-    """ Check optimization parameters before solving the problem
+    """Check optimization parameters before solving the problem
 
-        Parameters 
-        ----------
-        solver : Solver
-            solver to perform the genetic algorithm with DEAP
+    Parameters
+    ----------
+    solver : Solver
+        solver to perform the genetic algorithm with DEAP
     """
 
     logger = self.get_logger()
@@ -58,6 +58,18 @@ def check_optimization_input(self):
                 )
                 raise OptimizationAttributeError(mess)
 
+        # Check if objectives and other datakeepers have different symbol
+        if isinstance(self.problem.datakeeper_list, list):
+            symbol_list = [of.symbol for of in self.problem.obj_func] + [
+                dk.symbol for dk in self.problem.datakeeper_list
+            ]
+        else:
+            symbol_list = [of.symbol for of in self.problem.obj_func]
+
+        if len(symbol_list) != len(set(symbol_list)):
+            mess = "Every objective function and datakeeper must have a unique symbol."
+            raise OptimizationAttributeError(mess)
+
     # Check the problem contains at least one objective function
     if self.problem.design_var == None or (
         isinstance(self.problem.design_var, list) and len(self.problem.design_var) == 0
@@ -97,7 +109,9 @@ def check_optimization_input(self):
                 raise OptimizationAttributeError(mess)
             # Check getter
             elif not callable(cstr.get_variable):
-                mess = "The constraint '{}' function get_variable is not callable.".format(
-                    cstr.name
+                mess = (
+                    "The constraint '{}' function get_variable is not callable.".format(
+                        cstr.name
+                    )
                 )
                 raise OptimizationAttributeError(mess)
