@@ -1,57 +1,43 @@
-from numpy import pi, array, all as np_all
-from SciDataTool import Data1D, DataTime, VectorField
+from numpy import pi, all as np_all
+from SciDataTool import DataTime, VectorField
 
 
-def comp_force(self, output):
+def comp_force(self, output, axes_dict):
     """Compute the air-gap surface force based on Maxwell Tensor (MT).
 
     Parameters
     ----------
     self : ForceMT
         A ForceMT object
-
     output : Output
         an Output object (to update)
+    axes_dict: {Data}
+        Dict of axes used for force calculation
     """
 
-    # Get time and angular axes without anti-periodicity in axes
-    Angle_comp, Time_comp = self.get_axes(
-        output, is_remove_apera=True, is_remove_apert=True
-    )
-    # Check if the angular axis is anti-periodic
-    _, is_antiper_a = Angle_comp.get_periodicity()
+    # Get time and angular axes
+    Angle = axes_dict["Angle"]
+    Time = axes_dict["Time"]
 
-    # Import angular vector from Data object
-    angle = Angle_comp.get_values(
+    # Import angular vector from Angle Data object
+    _, is_antiper_a = Angle.get_periodicity()
+    angle = Angle.get_values(
         is_oneperiod=self.is_periodicity_a,
         is_antiperiod=is_antiper_a and self.is_periodicity_a,
     )
 
-    # Check if the angular axis is anti-periodic
-    _, is_antiper_t = Time_comp.get_periodicity()
-
-    time = Time_comp.get_values(
+    # Import time vector from Time Data object
+    _, is_antiper_t = Time.get_periodicity()
+    time = Time.get_values(
         is_oneperiod=self.is_periodicity_t,
         is_antiperiod=is_antiper_t and self.is_periodicity_t,
     )
 
-    # Initialize list of axes and symmetry dict for VectorField P
-    axes_list = list(output.mag.B.get_axes())
-    sym_dict = dict()
-
-    # Update axes and symmetry lists by removing anti-periodicity
-    for ii, axe in enumerate(axes_list):
-        if axe.name == Angle_comp.name:
-            axes_list[ii] = Angle_comp
-        if axe.name == Time_comp.name:
-            axes_list[ii] = Time_comp
-
-        if axes_list[ii].symmetries:
-            sym_dict.update(axes_list[ii].symmetries)
-
     # Load magnetic flux
     Brphiz = output.mag.B.get_rphiz_along(
-        "time=axis_data1", "angle=axis_data2", axis_data=[time, angle],
+        "time=axis_data",
+        "angle=axis_data",
+        axis_data={"time": time, "angle": angle},
     )
     Br = Brphiz["radial"]
     Bt = Brphiz["tangential"]
@@ -65,7 +51,18 @@ def comp_force(self, output):
     Ptan = Br * Bt / mu_0
     Pz = Br * Bz / mu_0
 
-    # Store the results
+    # Store Maxwell Stress tensor P in VectorField
+    # Build axes list
+    axes_list = list()
+    for axe in output.mag.B.get_axes():
+        if axe.name == Angle.name:
+            axes_list.append(Angle)
+        elif axe.name == Time.name:
+            axes_list.append(Time)
+        else:
+            axes_list.append(axe)
+
+    # Build components list
     components = {}
     if not np_all((Prad == 0)):
         Prad_data = DataTime(
@@ -73,7 +70,6 @@ def comp_force(self, output):
             unit="N/m2",
             symbol="P_r",
             axes=axes_list,
-            symmetries=sym_dict,
             values=Prad,
         )
         components["radial"] = Prad_data
@@ -83,7 +79,6 @@ def comp_force(self, output):
             unit="N/m2",
             symbol="P_t",
             axes=axes_list,
-            symmetries=sym_dict,
             values=Ptan,
         )
         components["tangential"] = Ptan_data
@@ -93,10 +88,11 @@ def comp_force(self, output):
             unit="N/m2",
             symbol="P_z",
             axes=axes_list,
-            symmetries=sym_dict,
             values=Pz,
         )
         components["axial"] = Pz_data
+
+    # Store components in VectorField
     output.force.P = VectorField(
         name="Magnetic airgap surface force", symbol="P", components=components
     )
