@@ -20,11 +20,8 @@ def get_surface_wind(self, alpha=0, delta=0):
         Surface corresponding to the Winding Area
     """
 
-    # check if the slot is on the stator
-    if self.get_is_stator():
-        st = "S"
-    else:
-        st = "R"
+    # get the name of the lamination
+    st = self.get_name_lam()
 
     # Create curve list
     curve_list = self.build_geometry()[1:-1]
@@ -43,7 +40,7 @@ def get_surface_wind(self, alpha=0, delta=0):
     else:
         Zmid = self.get_Rbo() - self.H0 - self.H2 / 2
     surface = SurfLine(
-        line_list=curve_list, label="Wind" + st + "_R0_T0_S0", point_ref=Zmid
+        line_list=curve_list, label="Wind_" + st + "_R0_T0_S0", point_ref=Zmid
     )
 
     # Apply transformation
